# remirepo/fedora spec file for php-tecnickcom-tc-lib-pdf-encrypt
#
# Copyright (c) 2016-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    8d55aad6ddaaed7148dba8ff1595b7d287c06b5b
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-pdf-encrypt
%global php_project  %{_datadir}/php/Com/Tecnick/Pdf/Encrypt
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        1.6.7
Release:        1%{?dist}
Summary:        PHP library to encrypt data for PDF

License:        LGPLv3+
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
BuildRequires:  php(language) >= 5.4
BuildRequires:  php-date
BuildRequires:  php-hash
BuildRequires:  php-openssl
BuildRequires:  php-pcre
BuildRequires:  php-posix
%if 0%{?fedora} >= 32 || 0%{?rhel} >= 9
%global phpunit %{_bindir}/phpunit9
BuildRequires:  phpunit9 >= 9.5.0
%else
%global phpunit %{_bindir}/phpunit8
BuildRequires:  phpunit8 >= 8.5.13
%endif
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": ">=5.4",
#        "ext-date": "*",
#        "ext-hash": "*",
#        "ext-openssl": "*",
#        "ext-pcre": "*",
Requires:       php(language) >= 5.4
Requires:       php-date
Requires:       php-hash
Requires:       php-openssl
Requires:       php-pcre
# From composer.json, "suggest": {
#        "ext-posix": "*"
Requires:       php-posix
# From phpcompatinfo report for version 1.5.0
# none
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library to encrypt data for PDF.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Sanity check
grep -q '^%{version}$' VERSION


%build
phpab --template fedora --output src/autoload.php src


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
date_default_timezone_set("UTC");
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
VER=$(php -r 'echo (OPENSSL_VERSION_NUMBER>>28);')
if [ $VER -ge 3 ]; then
  FILTER="--filter '^((?!(testEncryptPubThree|testEncryptPubNoP|testEncryptModZeroPub|testGetPdfEncryptionObjThreePub|testGetPdfEncryptionObjOnePub|testGetEncryptionData|testGetObjectKey|testEncryptStringEnabled|testEscapeDataStringEnabled|testGetPdfEncryptionObjOne|testGetPdfEncryptionObjZero)).)*$'"
fi
for cmdarg in "php %{phpunit}" php74 php80 php81; do
   if which $cmdarg; then
      set $cmdarg
      $1 ${2:-%{_bindir}/phpunit9} $FILTER --no-coverage --verbose || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc README.md
%dir %{_datadir}/php/Com
%dir %{_datadir}/php/Com/Tecnick
%dir %{_datadir}/php/Com/Tecnick/Pdf
%{php_project}


%changelog
* Mon Jan  3 2022 Remi Collet <remi@remirepo.net> - 1.6.7-1
- update to 1.6.7 (no change)

* Thu Nov 11 2021 Remi Collet <remi@remirepo.net> - 1.6.4-2
- skip test failing with OpenSSL 3.0 reported as
  https://github.com/tecnickcom/tc-lib-pdf-encrypt/issues/10

* Mon Feb  8 2021 Remi Collet <remi@remirepo.net> - 1.6.4-1
- update to 1.6.4 (no change)

* Mon Dec 21 2020 Remi Collet <remi@remirepo.net> - 1.6.1-1
- update to 1.6.1
- switch to classmap autoloader

* Fri Jan  3 2020 Remi Collet <remi@remirepo.net> - 1.5.10-1
- update to 1.5.10 (no change)

* Thu Jan  2 2020 Remi Collet <remi@remirepo.net> - 1.5.9-1
- update to 1.5.9 (no change)

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.5.8-1
- update to 1.5.8 (no change)

* Mon Jun 25 2018 Remi Collet <remi@remirepo.net> - 1.5.7-1
- update to 1.5.7 (no change)

* Mon May 14 2018 Remi Collet <remi@remirepo.net> - 1.5.6-1
- update to 1.5.6 (no change)
- switch to phpunit7

* Tue Jan  2 2018 Remi Collet <remi@remirepo.net> - 1.5.4-1
- Update to 1.5.4

* Sun Oct 29 2017 Remi Collet <remi@remirepo.net> - 1.5.3-1
- Update to 1.5.3
- use phpunit6 when available

* Sun Feb 12 2017 Remi Collet <remi@fedoraproject.org> - 1.5.2-1
- update to 1.5.2 (no change)

* Wed Feb  8 2017 Remi Collet <remi@fedoraproject.org> - 1.5.0-1
- update to 1.5.0
- drop dependency on php-mcrypt

* Mon Feb  6 2017 Remi Collet <remi@fedoraproject.org> - 1.4.4-1
- update to 1.4.4 (no change)
- open https://github.com/tecnickcom/tc-lib-pdf-encrypt/issues/4 - 7.1 failure
- open https://github.com/tecnickcom/tc-lib-pdf-encrypt/pull/5 add 7.1 to travis
- open https://github.com/tecnickcom/tc-lib-pdf-encrypt/pull/6 better exception

* Fri Sep  2 2016 Remi Collet <remi@fedoraproject.org> - 1.4.3-1
- update to 1.4.3

* Tue Jun 14 2016 Remi Collet <remi@fedoraproject.org> - 1.4.0-1
- update to 1.4.0 (no change)

* Fri Mar  4 2016 Remi Collet <remi@fedoraproject.org> - 1.3.2-1
- update to 1.3.2 (no change)

* Fri Jan 15 2016 Remi Collet <remi@fedoraproject.org> - 1.3.0-1
- initial package, version 1.3.0

